# History

# 0.3.0 (2020-07-23)

* Update testdata and subset module (#34).

# 0.2.1 (2020-07-08)

* Fixed docs version (#25).

## 0.2.0 (2020-06-19)

* Integration of xclim subset module in `clisops.core.subset`.
* Added jupyter notebook with and example for subsetting from xclim.
* Fixed RTD doc build.
* Updated travis CI according to xclim requirements.
* Now employing PEP8 + Black compatible autoformatting.
* Pre-commit is now used to launch code formatting inspections for local development.

## 0.1.0 (2020-04-22)

* First release.
